@@ -12,7 +12,13 @@ get_el_recurse <- function(
 
     if (is.null(obj) || identical(obj, "")) {
 
-      obj <- cast_to_type(NA, type)
+      obj <- switch(
+        type,
+        double = NA_real_,
+        integer = NA_integer_,
+        logical = NA,
+        NA_character_
+      )
 
     }
 
@@ -50,7 +56,13 @@ get_el_recurse <- function(
 
     null_elements <- vapply(next_obj, is.null, NA)
 
-    next_obj[null_elements] <- cast_to_type(NA, type)
+    next_obj[null_elements] <- switch(
+      type,
+      double = NA_real_,
+      integer = NA_integer_,
+      logical = NA,
+      NA_character_
+    )
 
     next_obj <- unlist(next_obj, recursive = FALSE)
 
@@ -321,34 +333,6 @@ cache_is_valid <- function(timeout, created) {
 
 }
 
-#' @noRd
-
-infer_cache <- function(cache) {
-
-  ans <- getOption("finbif_use_cache_metadata")
-
-  if (is.logical(cache)) {
-
-    if (is.logical(ans)) {
-
-      ans <- cache || ans
-
-    }
-
-  } else {
-
-    if (is.logical(ans)) {
-
-      ans <- cache
-
-    }
-
-  }
-
-  ans
-
-}
-
 # random sampling --------------------------------------------------------------
 
 #' @noRd
@@ -540,7 +524,7 @@ get_locale <- function() {
 
   ans <- "en"
 
-  supported <- sysdata("supported_langs")
+  supported <- sysdata(list(which = "supported_langs"))
 
   matches <- name_chr_vec(c(unname(supported), supported))
 
@@ -587,7 +571,7 @@ with_locale <- function(
 
     nms <- names(x)
 
-    supported_langs <- sysdata("supported_langs")
+    supported_langs <- sysdata(list(which = "supported_langs"))
 
     locales <- setdiff(supported_langs, locale)
 
